pub async fn run_decode(
body: &[u8],
steps: &[DecodeStep],
) -> Result<Vec<Value>, FaucetError>Expand description
Run the decode chain over the response body, returning records.
pub async fn run_decode(
body: &[u8],
steps: &[DecodeStep],
) -> Result<Vec<Value>, FaucetError>Run the decode chain over the response body, returning records.